@@ -2,6 +2,12 @@
 
 package color
 
+import "errors"
+
+func GetAccentColor() (*RGB, error) {
+	return nil, errors.New("not implemented")
+}
+
 func (d *DefaultColors) SetAccentColor(defaultColor string) {
 	if len(defaultColor) == 0 {
 		return
