@@ -44,13 +44,14 @@ type Block struct {
 	previousActiveSegment *Segment
 }
 
-func (b *Block) init(env environment.Environment, writer color.Writer, ansi *color.Ansi) {
+func (b *Block) Init(env environment.Environment, writer color.Writer, ansi *color.Ansi) {
 	b.env = env
 	b.writer = writer
 	b.ansi = ansi
+	b.executeSegmentLogic()
 }
 
-func (b *Block) initPlain(env environment.Environment, config *Config) {
+func (b *Block) InitPlain(env environment.Environment, config *Config) {
 	b.ansi = &color.Ansi{}
 	b.ansi.InitPlain(env.Shell())
 	b.writer = &color.AnsiWriter{
@@ -59,6 +60,15 @@ func (b *Block) initPlain(env environment.Environment, config *Config) {
 		AnsiColors:         config.MakeColors(env),
 	}
 	b.env = env
+	b.executeSegmentLogic()
+}
+
+func (b *Block) executeSegmentLogic() {
+	if b.env.Flags().Debug {
+		return
+	}
+	b.setEnabledSegments()
+	b.setSegmentsText()
 }
 
 func (b *Block) setActiveSegment(segment *Segment) {
@@ -66,56 +76,68 @@ func (b *Block) setActiveSegment(segment *Segment) {
 	b.writer.SetColors(segment.background(), segment.foreground())
 }
 
-func (b *Block) enabled() bool {
+func (b *Block) Enabled() bool {
 	if b.Type == LineBreak {
 		return true
 	}
 	for _, segment := range b.Segments {
-		if segment.enabled {
+		if segment.Enabled {
 			return true
 		}
 	}
 	return false
 }
 
-func (b *Block) renderSegmentsText() {
+func (b *Block) setEnabledSegments() {
 	wg := sync.WaitGroup{}
 	wg.Add(len(b.Segments))
 	defer wg.Wait()
 	for _, segment := range b.Segments {
 		go func(s *Segment) {
 			defer wg.Done()
-			s.renderText(b.env)
+			s.SetEnabled(b.env)
 		}(segment)
 	}
 }
 
-func (b *Block) renderSegments() (string, int) {
+func (b *Block) setSegmentsText() {
+	wg := sync.WaitGroup{}
+	wg.Add(len(b.Segments))
+	defer wg.Wait()
+	for _, segment := range b.Segments {
+		go func(s *Segment) {
+			defer wg.Done()
+			s.SetText()
+		}(segment)
+	}
+}
+
+func (b *Block) RenderSegments() (string, int) {
 	defer b.writer.Reset()
 	for _, segment := range b.Segments {
-		if !segment.enabled && segment.Style != Accordion {
+		if !segment.Enabled && segment.Style != Accordion {
 			continue
 		}
-		b.renderSegment(segment)
+		b.setActiveSegment(segment)
+		b.renderActiveSegment()
 	}
 	b.writePowerline(true)
 	b.writer.ClearParentColors()
 	return b.writer.String()
 }
 
-func (b *Block) renderSegment(segment *Segment) {
-	b.setActiveSegment(segment)
+func (b *Block) renderActiveSegment() {
 	b.writePowerline(false)
 	switch b.activeSegment.Style {
 	case Plain, Powerline:
-		b.writer.Write(color.Background, color.Foreground, segment.text)
+		b.writer.Write(color.Background, color.Foreground, b.activeSegment.text)
 	case Diamond:
 		b.writer.Write(color.Transparent, color.Background, b.activeSegment.LeadingDiamond)
-		b.writer.Write(color.Background, color.Foreground, segment.text)
+		b.writer.Write(color.Background, color.Foreground, b.activeSegment.text)
 		b.writer.Write(color.Transparent, color.Background, b.activeSegment.TrailingDiamond)
 	case Accordion:
-		if segment.enabled {
-			b.writer.Write(color.Background, color.Foreground, segment.text)
+		if b.activeSegment.Enabled {
+			b.writer.Write(color.Background, color.Foreground, b.activeSegment.text)
 		}
 	}
 	b.previousActiveSegment = b.activeSegment
@@ -166,7 +188,7 @@ func (b *Block) getPowerlineColor() string {
 	return b.previousActiveSegment.background()
 }
 
-func (b *Block) debug() (int, []*SegmentTiming) {
+func (b *Block) Debug() (int, []*SegmentTiming) {
 	var segmentTimings []*SegmentTiming
 	largestSegmentNameLength := 0
 	for _, segment := range b.Segments {
@@ -177,11 +199,12 @@ func (b *Block) debug() (int, []*SegmentTiming) {
 			largestSegmentNameLength = segmentTiming.nameLength
 		}
 		start := time.Now()
-		segment.renderText(b.env)
-		segmentTiming.active = segment.enabled
-		segmentTiming.text = segment.text
-		if segmentTiming.active {
-			b.renderSegment(segment)
+		segment.SetEnabled(b.env)
+		segment.SetText()
+		segmentTiming.active = segment.Enabled
+		if segmentTiming.active || segment.Style == Accordion {
+			b.setActiveSegment(segment)
+			b.renderActiveSegment()
 			segmentTiming.text, _ = b.writer.String()
 			b.writer.Reset()
 		}
